<?php
/**
 * Customize API: WP_Customize_Color_Control class
 *
 * @package WordPress
 * @subpackage Customize
 * @since 4.4.0
 */

/**
 * Customize Color Control class.
 *
 * @since 3.4.0
 *
 * @see WP_Customize_Control
 */

if( class_exists( 'WP_Customize_Control' ) ):

	class HayyaFonts extends WP_Customize_Control {


		/**
		 * Type.
		 *
		 * @var string
		 */
		public $type = 'font';

		/**
		 *
		 * @var string
		 */
		public $fonts = array();

		/**
		 * Enqueue scripts/styles for the color picker.
		 *
		 * @since 3.4.0
		 */
		public function enqueue() {
			$theme = wp_get_theme('hayya');
			wp_enqueue_script(
				'chosen',
				get_template_directory_uri() . '/includes/extensions/google-fonts/assets/chosen.jquery.min.js',
				array('jquery'),
				$theme->get( 'Version' ),
				true
			);
			wp_enqueue_script(
				'hayya-fonts',
				get_template_directory_uri() . '/includes/extensions/google-fonts/assets/hayya-fonts.min.js',
				array('chosen'),
				$theme->get( 'Version' ),
				true
			);

			wp_enqueue_style(
				'chosen',
				get_template_directory_uri() . '/includes/extensions/google-fonts/assets/chosen.min.css',
				array(),
				$theme->get( 'Version' )
			);
			wp_enqueue_style(
				'hayya-fonts',
				get_template_directory_uri() . '/includes/extensions/google-fonts/assets/hayya-fonts.min.css',
				array('chosen'),
				$theme->get( 'Version' )
			);
		}

		/**
		 * Don't render the control content from PHP, as it's rendered via JS on load.
		 *
		 * @since 3.4.0
		 */
		public function render_content() {

			// $value = $this->value();
			// // var_dump($this);
			// echo '========>'.$this->value('body-font-link');
			?>
			<div style="padding-bottom: 100px;">
				<strong><?php echo esc_html( $this->label ); ?></strong>
				<hr/>
				<div class="hayya-fonts">

					<label for="body-font"><?php esc_attr_e('Body Font', 'hayya') ?></label>
					<select name="body-font" class="chosen-select" data-placeholder="<?php esc_attr_e('Select Font Famly', 'hayya');?>" <?php $this->link('body-font-link'); ?>>
						<?php $this->font_options( $this->value('body-font-link') ); ?>
					</select>
					<label for="body-size"><?php esc_attr_e('Body Font Size', 'hayya') ?></label>
					<input type="range" name="body-size" value="<?php echo esc_attr($this->value('body-size-link')); ?>" <?php $this->link('body-size-link'); ?> min="0.9" max="4" step="0.01" class="range-slide" />
					<div id="body-size-value" class="range-value"><?php echo esc_attr($this->value('body-size-link')); ?>rem</div>

					<hr/>
					<label for="h1-font"><?php esc_attr_e('H1 Font', 'hayya') ?></label>
					<select name="h1-font" class="chosen-select" data-placeholder="<?php esc_attr_e('Select Font Famly', 'hayya');?>" <?php $this->link('h1-font-link'); ?>>
						<?php $this->font_options( $this->value('h1-font-link') ); ?>
					</select>
					<label for="h1-size"><?php esc_attr_e('H1 Font Size', 'hayya') ?></label>
					<input type="range" id="h1-size" name="h1-size" value="<?php echo esc_attr($this->value('h1-size-link')); ?>" <?php $this->link('h1-size-link'); ?> min="1" max="6" step="0.01" class="range-slide" />
					<div id="h1-size-value" class="range-value"><?php echo esc_attr($this->value('h1-size-link')); ?>rem</div>

					<hr/>
					<label for="h2-font"><?php esc_attr_e('H2 Font', 'hayya') ?></label>
					<select name="h2-font" class="chosen-select" data-placeholder="<?php esc_attr_e('Select Font Famly', 'hayya');?>" <?php $this->link('h2-font-link'); ?>>
						<?php $this->font_options( $this->value('h2-fon-linkt') ); ?>
					</select>
					<label for="h2-size"><?php esc_attr_e('H2 Font Size', 'hayya') ?></label>
					<input type="range" name="h2-size" value="<?php echo esc_attr($this->value('h2-size-link')); ?>" <?php $this->link('h2-size-link'); ?> min="0.5" max="5" step="0.01" class="range-slide" />
					<div id="h2-size-value" class="range-value"><?php echo esc_attr($this->value('h2-size-link')); ?>rem</div>

					<hr/>
					<label for="h3-font"><?php esc_attr_e('H3 Font', 'hayya') ?></label>
					<select name="h3-font" class="chosen-select" data-placeholder="<?php esc_attr_e('Select Font Famly', 'hayya');?>" <?php $this->link('h3-font-link'); ?>>
						<?php $this->font_options( $this->value('h3-font-link') ); ?>
					</select>
					<label for="h3-size"><?php esc_attr_e('H3 Font Size', 'hayya') ?></label>
					<input type="range" name="h3-size" value="<?php echo esc_attr($this->value('h3-size-link')); ?>" <?php $this->link('h3-size-link'); ?> min="0.5" max="4" step="0.01" class="range-slide" />
					<div id="h3-size-value" class="range-value"><?php echo esc_attr($this->value('h3-size-link')); ?>rem</div>

					<hr/>
					<label for="h4-font"><?php esc_attr_e('H4 Font', 'hayya') ?></label>
					<select name="h4-font" class="chosen-select" data-placeholder="<?php esc_attr_e('Select Font Famly', 'hayya');?>" <?php $this->link('h4-font-link'); ?>>
						<?php $this->font_options( $this->value('h4-font-link') ); ?>
					</select>
					<label for="h4-size"><?php esc_attr_e('H4 Font Size', 'hayya') ?></label>
					<input type="range" name="h4-size" value="<?php echo esc_attr($this->value('h4-size-link')); ?>" <?php $this->link('h4-size-link'); ?> min="0.4" max="4" step="0.01" class="range-slide" />
					<div id="h4-size-value" class="range-value"><?php echo esc_attr($this->value('h4-size-link')); ?>rem</div>

					<hr/>
					<label for="h5-font"><?php esc_attr_e('H5 Font', 'hayya') ?></label>
					<select name="h5-font" class="chosen-select" data-placeholder="<?php esc_attr_e('Select Font Famly', 'hayya');?>" <?php $this->link('h5-font-link'); ?>>
						<?php $this->font_options( $this->value('h5-font-link') ); ?>
					</select>
					<label for="h5-size"><?php esc_attr_e('H5 Font Size', 'hayya') ?></label>
					<input type="range" name="h5-size" value="<?php echo esc_attr($this->value('h5-size-link')); ?>" <?php $this->link('h5-size-link'); ?> min="0.3" max="4" step="0.01" class="range-slide" />
					<div id="h5-size-value" class="range-value"><?php echo esc_attr($this->value('h5-size-link')); ?>rem</div>

					<hr/>
					<label for="h6-font"><?php esc_attr_e('H6 Font', 'hayya') ?></label>
					<select name="h6-font" class="chosen-select" data-placeholder="<?php esc_attr_e('Select Font Famly', 'hayya');?>" <?php $this->link('h6-font-link'); ?>>
						<?php $this->font_options( $this->value('h6-font-link') ); ?>
					</select>
					<label for="h6-size"><?php esc_attr_e('H6 Font Size', 'hayya') ?></label>
					<input type="range" name="h6-size" value="<?php echo esc_attr($this->value('h6-size-link')); ?>" <?php $this->link('h6-size-link'); ?> min="0.3" max="4" step="0.01"  class="range-slide" />
					<div id="h6-size-value" class="range-value"><?php echo esc_attr( $this->value('h6-size-link') ); ?>rem</div>

				</div>
			  </div>
			<?php
		}

		private function font_options( $value = '' ) {
			$sFonts = array(
				"Arial, Helvetica, sans-serif"						 => "Arial, Helvetica, sans-serif",
				"'Arial Black', Gadget, sans-serif"					=> "'Arial Black', Gadget, sans-serif",
				"'Bookman Old Style', serif"						   => "'Bookman Old Style', serif",
				"'Comic Sans MS', cursive"							 => "'Comic Sans MS', cursive",
				"Courier, monospace"								   => "Courier, monospace",
				"Garamond, serif"									  => "Garamond, serif",
				"Georgia, serif"									   => "Georgia, serif",
				"Impact, Charcoal, sans-serif"						 => "Impact, Charcoal, sans-serif",
				"'Lucida Console', Monaco, monospace"				  => "'Lucida Console', Monaco, monospace",
				"'Lucida Sans Unicode', 'Lucida Grande', sans-serif"   => "'Lucida Sans Unicode', 'Lucida Grande', sans-serif",
				"'MS Sans Serif', Geneva, sans-serif"				  => "'MS Sans Serif', Geneva, sans-serif",
				"'MS Serif', 'New York', sans-serif"				   => "'MS Serif', 'New York', sans-serif",
				"'Palatino Linotype', 'Book Antiqua', Palatino, serif" => "'Palatino Linotype', 'Book Antiqua', Palatino, serif",
				"Tahoma,Geneva, sans-serif"							=> "Tahoma, Geneva, sans-serif",
				"'Times New Roman', Times,serif"					   => "'Times New Roman', Times, serif",
				"'Trebuchet MS', Helvetica, sans-serif"				=> "'Trebuchet MS', Helvetica, sans-serif",
				"Verdana, Geneva, sans-serif"						  => "Verdana, Geneva, sans-serif",
			);

			$gFile = dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'googlefonts.php';
			if ( file_exists($gFile) ) $f = include $gFile;
			$gFonts = array();
			if ( isset( $f ) && ! empty( $f ) && is_array( $f ) && $f != false ) {
				foreach ( $f as $k => $v ) {
					$gFonts[] = $k;
				}
			}
			?>
			<option value=""></option>
			<optgroup label="<?php esc_attr_e('Standard Fonts', 'hayya'); ?>">
			<?php
			if ( isset($sFonts) && ! empty($sFonts) && is_array($sFonts) ) {
				foreach ( $sFonts as $v ) {
					if ( ! empty($v) && ! is_array($v) ) {
						if ( $value ===  $v ) $selected = 'selected';
						else $selected = '';
						echo '<option vlaue="'.esc_attr($v).'" '.esc_attr($selected),'>'.esc_attr($v).'</option>';
					}
				}
				unset($v);
			}
			?>
			</optgroup>
			<optgroup label="<?php esc_attr_e('Google WebFonts', 'hayya'); ?>">
			<?php
			if ( isset($gFonts) && ! empty($gFonts) && is_array($gFonts) ) {
				foreach ( $gFonts as $v ) {
					if ( ! empty($v) && ! is_array($v) ) {
						if ( $value ===  $v ) $selected = 'selected';
						else $selected = '';
						echo '<option vlaue="'.esc_attr($v).'" '.esc_attr($selected),'>'.esc_attr($v).'</option>';
					}
				}
			}
			?>
			</optgroup>
			<?php
		}

	}

endif;
